{%raw%}

<script id="wherelabel-template" type="text/x-underscore-template">
<div class='clause'>
  <button data-idx="{{idx}}" type="button" class="close" aria-hidden="true">&times;</button>
  {{ sql }}
</div>
</script>

{%endraw%}
