<div  class="row">
  <div id="footer" class="col-md-12">
    <a href="mailto: eugenewu@mit.edu">eugene wu</a> 
    & <a href="http://www.mit.edu/~eugenewu/dbwipes.html">the related page</a>
  </div>
</div>


